@@ -16,25 +16,24 @@
 # You should have received a copy of the GNU General Public License
 # along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
 
-import gtk
-from gnomedvb.ui.widgets.Frame import AlignedLabel
+import gobject
+from gi.repository import Gtk
 
-class BasePage(gtk.VBox):
+class BasePage(Gtk.VBox):
 
     def __init__(self):
-        gtk.VBox.__init__(self, spacing=6)
+        gobject.GObject.__init__(self, spacing=6)
         self.set_border_width(24)
 
-        ali = AlignedLabel()
-        ali.show()
-        self.pack_start(ali, False, False)
-
-        self._label = ali.get_label()
+        self._label = Gtk.Label()
+        self._label.set_halign(Gtk.Align.START)
         self._label.set_line_wrap(True)
+
+        self.pack_start(self._label, False, False, 0)
         
     def get_page_title(self):
         raise NotImplementedError
         
     def get_page_type(self):
-        return gtk.ASSISTANT_PAGE_CONTENT
+        return Gtk.AssistantPageType.CONTENT
 
